<?php
namespace App\Customer\Entity\Contact;
use Dedi\SyliusContactPlugin\Repository\ContactFormSubjectRepositoryInterface;
use Sylius\Bundle\ResourceBundle\Form\Type\AbstractResourceType;
use Sylius\Component\Locale\Context\LocaleContextInterface;
use Symfony\Bridge\Doctrine\Form\Type\EntityType;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\NotBlank;

class ContactFormSubjectEntityType extends AbstractResourceType
{
    private LocaleContextInterface $localeContext;
    public function __construct(string $dataClass, array $validationGroups, LocaleContextInterface $localeContext)
    {
        parent::__construct($dataClass, $validationGroups);
        $this->localeContext = $localeContext;
    }
    public function configureOptions(OptionsResolver $resolver): void
    {
        parent::configureOptions($resolver);
        $resolver->setDefaults([
            'class' => $this->dataClass,
            'label' => 'dedi_sylius_contact_form.ui.form.subject',
            'choice_label' => 'label',
            'choice_value' => 'id',
            'query_builder' => function (ContactFormSubjectRepositoryInterface $er) {
                return $er
                    ->createTranslationBasedQueryBuilder($this->localeContext->getLocaleCode())
                    ->andWhere('o.active = :status')
                    ->orderBy('o.subjectRank')
                    ->setParameter('status', 1);
            },
            'constraints' => [
                new NotBlank(['groups' => ['default', 'sylius']]),
            ],
        ]);
    }
    public function getParent()
    {
        return EntityType::class;
    }
}

